import { Body, Controller, Delete, Param, Post, Put } from '@nestjs/common';
import { ExcludePrivilege, Public } from 'src/core/guards';
import { ApiBearerAuth } from '@nestjs/swagger';
import { LoginDto } from './dto/login.dto';
import { AuthAdminQueueOrchestrator } from '../domain/auth-admin-queue.orchestrator';

@Controller('v1/auth/queue')
export class AuthAdminQueueController {
  constructor(private orchestrator: AuthAdminQueueOrchestrator) {}

  @Post()
  @Public(true)
  async login(@Body() body: LoginDto) {
    return await this.orchestrator.login(body);
  }

  @ApiBearerAuth('JWT')
  @Public(false)
  @ExcludePrivilege()
  @Delete('logout')
  async logoout() {
    return await this.orchestrator.logout();
  }

  @Put(':id/logout')
  async logoutQueueAdmin(@Param('id') dataId: string) {
    return await this.orchestrator.logout(dataId);
  }
}
